# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# http://www.sphinx-doc.org/en/master/config

from pkg_resources import get_distribution, DistributionNotFound

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.autosummary',
    'sphinx.ext.coverage',
    'sphinx.ext.doctest',
    'sphinx.ext.intersphinx',
    'sphinx.ext.mathjax',
    'sphinx.ext.napoleon',
    'sphinx.ext.todo',
    'sphinx.ext.viewcode',
    'sphinxcontrib.plantuml'
]

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'GROMACS scripting and extension API'
copyright = u'2017, M. Eric Irrgang and Peter Kasson; 2019, GROMACS development team'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
try:
    release = str(get_distribution('gmxapi').version)
    version = '.'.join(release.split('.')[:2])
except DistributionNotFound:
    # package is not installed
    pass

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# Read the Docs looks pretty good.
html_theme = 'sphinx_rtd_theme'

# The name for this set of Sphinx documents.
# "<project> v<release> documentation" by default.
#
html_title = u'GROMACS External Interfaces'

# A shorter title for the navigation bar.  Default is the same as html_title.
#
html_short_title = u'gmxapi'

# Output file base name for HTML help builder.
htmlhelp_basename = 'gmxapi'

# -- Options for Intersphinx -------------------------------------------------

intersphinx_mapping = {'python': ('https://docs.python.org/3', None)}

# -- Options for autodoc extension -------------------------------------------
# reference https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#configuration

# Functions imported from C modules cannot be introspected, and therefore the
# signature for such functions cannot be automatically determined. However, it is
# an often-used convention to put the signature into the first line of the
# function's docstring.
#
# If this boolean value is set to True (which is the default), autodoc will look
# at the first line of the docstring for functions and methods, and if it looks
# like a signature, use the line as the signature and remove it from the docstring
# content.
#
autodoc_docstring_signature = True

# autodoc_mock_imports This value contains a list of modules to be mocked up. This
# is useful when some external dependencies are not met at build time and break
# the building process.
#
# New in version 1.3.
#
autodoc_mock_imports = []

# See http://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autoclass_content
autoclass_content = 'both'

# -- Options for Napoleon extension ------------------------------------------
# reference https://www.sphinx-doc.org/en/master/usage/extensions/napoleon.html#configuration

# -- Options for plantuml extension ------------------------------------------

plantuml = '/usr/bin/plantuml'
